(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6398,        225]
NotebookOptionsPosition[      5648,        194]
NotebookOutlinePosition[      6011,        210]
CellTagsIndexPosition[      5968,        207]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "fluxes are given in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{"d", 
      StyleBox["N",
       FontSlant->"Italic"]}]], "/", 
    StyleBox[
     RowBox[{"d", 
      StyleBox["x",
       FontSlant->"Italic"]}]]}], TraditionalForm]]],
 "  (",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", 
    RowBox[{
     SubscriptBox["E", "\[Nu]"], "/", 
     SubscriptBox["m", "DM"]}]}], TraditionalForm]]],
 ") normalized per single DM annihilation. The format is\n\n\
DM\[Nu]Earth[\[Nu] flavour, primary][lm, lx]\nDM\[Nu]Sun[\[Nu] flavour, \
primary][lm, lx]\n\nwhere\n\nlm = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", 
     RowBox[{
      SubscriptBox["m", "DM"], "/", "GeV"}]}], "]"}], TraditionalForm]]],
 "\nlx = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", " ", "x"}], " ", "]"}], TraditionalForm]]],
 "\n\[Nu] flavour = \"e\" or \"\[Mu]\" or \"\[Tau]\" or  \"",
 Cell[BoxData[
  OverscriptBox["\"\<e\>\"", "_"]]],
 "\" or \"",
 Cell[BoxData[
  OverscriptBox["\"\<\[Mu]\>\"", "_"]]],
 "\" or \"",
 Cell[BoxData[
  OverscriptBox["\"\<\[Tau]\>\"", "_"]]],
 "\"\nprimary = \"b\" or \"\[Tau]\" or \"c\" or \"q\" or \"W\" or \"Z\" or \"\
\[Nu]\"\nThe primary \"\[Nu]\" is given only in the solar case, where it is \
non-trivial; for lx = 0 DM\[Nu]Sun gives the survival probability"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Get", "[", 
  "\"\</Users/mcirelli/Documents/mathematica/DMnu/Fluxes/DMnuEarth.nb\>\"", 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.`", ",", "2.9999999999999996`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}]}], "}"}], 
    ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DM\[Nu]Earth", "[", 
   RowBox[{
   "\"\<\!\(\*OverscriptBox[\(\[Mu]\), \(_\)]\)\>\"", ",", "\"\<Z\>\""}], 
   "]"}], "[", 
  RowBox[{"2", ",", 
   RowBox[{"-", "0.5"}]}], "]"}]], "Input"],

Cell[BoxData["0.3662433925267055`"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Get", "[", 
  "\"\</Users/mcirelli/Documents/mathematica/DMnu/Fluxes/DMnuSun.nb\>\"", 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.`", ",", "2.9999999999999996`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}]}], "}"}], 
    ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DM\[Nu]Sun", "[", 
   RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\[Nu]\>\""}], "]"}], "[", 
  RowBox[{"2", ",", "0"}], "]"}]], "Input"],

Cell[BoxData["0.18788358806390368`"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["\n",
  FontFamily->"Helvetica",
  FontSize->10],
 "\n",
 StyleBox["Note Added to Release 4 (February 2010)",
  FontColor->RGBColor[1, 0, 0]],
 ":\nRelease 4 fixes a numerical bug in ",
 "the production of the fluxes of anti-neutrinos after propagation from the \
Sun.",
 "\n\nPreviously, Release 3 (September 2007) had fixed a numerical bug in the \
implementation of the boost for top quark decays (modification are quite \
small and affect the t ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["t", "_"], TraditionalForm]]],
 " channel).\n \nPreviously, Release 2 (July 2007) had fixed an erroneous \
double counting of the prompt neutrino yield in W-boson decays (modifications \
affected the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SuperscriptBox["W", "+"],
     TraditionalForm], 
    SuperscriptBox["W", "-"]}], TraditionalForm]]],
 " and  t ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["t", "_"], TraditionalForm]]],
 " channels). A few parameters had also been updated (modifications are \
generally small or null). \n\n\nPlease also note the following comment that \
applies to all Releases:\nWe carry out all the computations for a discrete \
set of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "DM"], TraditionalForm]]],
 " equal to: \n\
{10.,30.,50.,70.,90.,100.,150.,200.,250.,300.,500.,700.,900.,1000.} GeV in \
the Earth case,  and to: \
{10.,30.,50.,70.,90.,100.,200.,300.,500.,700.,900.,1000.} GeV in the solar \
case.\nThen, the InterpolatingFunctions presented here interpolate to \
intermediate values: for the \"Z\" and \"W\" fluxes for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "DM"], TraditionalForm]]],
 " around 100 \[Rule] 200 GeV, they can be not extremely accurate, due to the \
contributions of the features from \"prompt neutrinos\" (see text). They \
should be however a good approximation. \nOther channels and masses do not \
present this issue."
}], "Text",
 CellChangeTimes->{{3.4754101833525143`*^9, 3.4754102286628437`*^9}, {
  3.475410268910861*^9, 3.47541027375972*^9}}]
},
Evaluator->"Kernel 3",
WindowSize->{1015, 730},
WindowMargins->{{49, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1401, 46, 200, "Text"],
Cell[CellGroupData[{
Cell[1971, 70, 131, 3, 27, "Input"],
Cell[2105, 75, 361, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2503, 93, 223, 7, 27, "Input"],
Cell[2729, 102, 46, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2812, 107, 129, 3, 27, "Input"],
Cell[2944, 112, 361, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3342, 130, 163, 4, 27, "Input"],
Cell[3508, 136, 47, 0, 27, "Output"]
}, Open  ]],
Cell[3570, 139, 2074, 53, 284, "Text"]
}
]
*)

(* End of internal cache information *)

